==> docfbe_2_2_31_55.zip: docfbe_2_2_31_55/source/TCFbEAmplifiedWeightedSumWithWeightedMultiplier.cpp <==
/*
    TCFbEAmplifiedWeightedSumWithWeightedMultiplier.cpp    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbEAmplifiedWeightedSumWithWeightedMultiplier.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^
__fastcall TCFbEAmplifiedWeightedSumWithWeightedMultiplier::TCFbEAmplifiedWeightedSumWithWeightedMultiplier(void)
    : TCFbEWeightedSum()
{
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbEAmplifiedWeightedSumWithWeightedMultiplier::~TCFbEAmplifiedWeightedSumWithWeightedMultiplier()
{
}

//---------------------------------------------------------------------------
// ȍ~Cprotected \bh
//---------------------------------------------------------------------------
// q̒l𓾂
double __fastcall TCFbEAmplifiedWeightedSumWithWeightedMultiplier::GetNumerator(int NeighborIndex)
{
    TCFbENeighbor*    Neighbor = (TCFbENeighbor*)this->NeighborList->Items[NeighborIndex];
    int Index = this->DataSet->PredictionTable->RowLabelList->IndexOf(Neighbor->Label);
    return Neighbor->Value * this->DataSet->PredictionTable->GetWeightedMultiplierOfRow(this->TargetRowIndex, Index, this->TargetColumnIndex) * Neighbor->Similarity;
}

//---------------------------------------------------------------------------

==> docfbe_2_3_35_62.zip: docfbe_2_2_35_62/source/TCFbEAmplifiedWeightedSumWithWeightedMultiplier.cpp <==
/*
    TCFbEAmplifiedWeightedSumWithWeightedMultiplier.cpp    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbEAmplifiedWeightedSumWithWeightedMultiplier.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^
__fastcall TCFbEAmplifiedWeightedSumWithWeightedMultiplier::TCFbEAmplifiedWeightedSumWithWeightedMultiplier(void)
    : TCFbEWeightedSum()
{
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbEAmplifiedWeightedSumWithWeightedMultiplier::~TCFbEAmplifiedWeightedSumWithWeightedMultiplier()
{
}

//---------------------------------------------------------------------------
// ȍ~Cprotected \bh
//---------------------------------------------------------------------------
// q̒l𓾂
double __fastcall TCFbEAmplifiedWeightedSumWithWeightedMultiplier::GetNumerator(int NeighborIndex)
{
    TCFbENeighbor*    Neighbor = (TCFbENeighbor*)this->NeighborList->Items[NeighborIndex];
    int Index = this->PredictionTable->GetRowLabelList()->IndexOf(Neighbor->GetLabel());
    return Neighbor->GetValue() * this->PredictionTable->GetWeightedMultiplierOfRow(this->TargetRowIndex, Index, this->TargetColumnIndex) * Neighbor->GetSimilarity();
}

//---------------------------------------------------------------------------
